@@ -350,14 +350,15 @@ class Email:
         self.__subject = subject
         self.__text_content = text_content
         self.__html_content = html_content
-        self.__attached_files = attached_files
+        self.__attached_files = self.__build_list(attached_files)
         self.__unsubscribe_mailto_link = unsubscribe_mailto_link
         self.__unsubscribe_url = unsubscribe_url
 
     @staticmethod
-    def __build_list(element_or_list):
-        return element_or_list and \
-            (element_or_list if isinstance(element_or_list, (list, set, tuple)) else [element_or_list])
+    def __build_list(element_or_list_like_object):
+        return element_or_list_like_object and (
+            element_or_list_like_object if isinstance(element_or_list_like_object, (list, set, tuple)) \
+            else [element_or_list_like_object])
 
     @property
     def are_unsubscribe_methods_available(self):
@@ -365,6 +366,13 @@ class Email:
 
     @property
     def attached_files(self):
+        """
+        Return the list of files to be attached to this email.
+
+
+        :return: A list of strings corresponding to the path and name of the
+            files to attach to this email.
+        """
         return self.__attached_files
 
     @property
